@@ -23,6 +23,8 @@ class charCheck:
 
 class dateCalc():
     def checkDate(dateToCheck):
+        if(dateToCheck == ''):
+            return
         today = date.today()
         today = str(today).split('-')
         bases = dateToCheck.split('/')
